# Библиотека Dubina

Библиотека для централизованного управления роботами-манипуляторами с поддержкой электронной очереди клиентов и веб-интерфейсом для мониторинга.

## Установка

```bash
pip install dubina